.. _advertisement:

Advertisement
=============

Weblate allows you to place advertisements inside emails and web pages. You can
add them in the admin interface, defining placement and timespan, when it
should be shown.

Active advertisements are chosen randomly to be displayed inside defined
placement.

When no advertisements are enabled, you can enable
:setting:`SELF_ADVERTISEMENT` to show advertisements for Weblate.
